@@ -1,6 +1,6 @@
 // 1999-08-11 bkoz
 
-// Copyright (C) 1999-2016 Free Software Foundation, Inc.
+// Copyright (C) 1999-2017 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -17,31 +17,21 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// The ARM simulator does not provide support for "fstat", which
-// causes "in_avail" to return an incorrect value.
-// { dg-do run { xfail arm*-*-elf arm*-*-eabi } }
-
 // 27.6.1.3 unformatted input functions
-// @require@ %-*.tst %-*.txt
-// @diff@ %-*.tst %-*.txt
-
-// { dg-require-fileio "" }
-// { dg-require-binary-io "" }
 
 #include <istream>
-#include <fstream>
+#include <sstream>
 #include <testsuite_hooks.h>
 
 // libstdc++/6746   
-void test13()
+void test12()
 {
   using namespace std;
-  bool test __attribute__((unused)) = true;
   streamsize sum = 0;
-  ifstream ifs("istream_unformatted-1.tst");
+  istringstream iss("shamma shamma");
       
   // test01
-  size_t i = ifs.rdbuf()->in_avail();
+  size_t i = iss.rdbuf()->in_avail();
   VERIFY( i != 0 );
     
   // test02
@@ -49,16 +39,16 @@ void test13()
   do
     {
       char buf[1024];
-      extracted = ifs.readsome(buf, sizeof buf);
+      extracted = iss.readsome(buf, sizeof buf);
       sum += extracted;
     }
-  while (ifs.good() && extracted);
+  while (iss.good() && extracted);
   VERIFY( sum != 0 );  
 }
- 
+
 int 
 main()
 {
-  test13();
+  test12();
   return 0;
 }
